@@ -58,11 +58,10 @@ namespace xsimd
             static inline B compute(const B& x)
             {
                 return horner<B,
-                    0x3daaaaab,
-                    0x3b638e39,
-                    0xbb2fb930,
-                    0xb970b359
-                >(x);
+                              0x3daaaaab,
+                              0x3b638e39,
+                              0xbb2fb930,
+                              0xb970b359>(x);
             }
 
             static inline B split_limit()
@@ -82,12 +81,12 @@ namespace xsimd
             static inline B compute(const B& x)
             {
                 return horner<B,
-                    0x3fb5555555555986ll, //   8.33333333333482257126E-2
-                    0x3f6c71c71b98c5fdll, //   3.47222221605458667310E-3
-                    0xbf65f72607d44fd7ll, //  -2.68132617805781232825E-3
-                    0xbf2e166b27e61d7cll, //  -2.29549961613378126380E-4
-                    0x3f49cc72592d7293ll  //   7.87311395793093628397E-4
-                >(x);
+                              0x3fb5555555555986ll,  //   8.33333333333482257126E-2
+                              0x3f6c71c71b98c5fdll,  //   3.47222221605458667310E-3
+                              0xbf65f72607d44fd7ll,  //  -2.68132617805781232825E-3
+                              0xbf2e166b27e61d7cll,  //  -2.29549961613378126380E-4
+                              0x3f49cc72592d7293ll  //   7.87311395793093628397E-4
+                              >(x);
             }
 
             static inline B split_limit()
@@ -155,15 +154,15 @@ namespace xsimd
             static inline B compute(const B& x)
             {
                 return horner<B,
-                    0x3f800000UL, //  9.999999757445841E-01
-                    0x3ed87799UL, //  4.227874605370421E-01
-                    0x3ed2d411UL, //  4.117741948434743E-01
-                    0x3da82a34UL, //  8.211174403261340E-02
-                    0x3d93ae7cUL, //  7.211014349068177E-02
-                    0x3b91db14UL, //  4.451165155708328E-03
-                    0x3ba90c99UL, //  5.158972571345137E-03
-                    0x3ad28b22UL  //  1.606319369134976E-03
-                >(x);
+                              0x3f800000UL,  //  9.999999757445841E-01
+                              0x3ed87799UL,  //  4.227874605370421E-01
+                              0x3ed2d411UL,  //  4.117741948434743E-01
+                              0x3da82a34UL,  //  8.211174403261340E-02
+                              0x3d93ae7cUL,  //  7.211014349068177E-02
+                              0x3b91db14UL,  //  4.451165155708328E-03
+                              0x3ba90c99UL,  //  5.158972571345137E-03
+                              0x3ad28b22UL  //  1.606319369134976E-03
+                              >(x);
             }
         };
 
@@ -173,24 +172,24 @@ namespace xsimd
             static inline B compute(const B& x)
             {
                 return horner<B,
-                    0x3ff0000000000000ULL, // 9.99999999999999996796E-1
-                    0x3fdfa1373993e312ULL, // 4.94214826801497100753E-1
-                    0x3fca8da9dcae7d31ULL, // 2.07448227648435975150E-1
-                    0x3fa863d918c423d3ULL, // 4.76367800457137231464E-2
-                    0x3f8557cde9db14b0ULL, // 1.04213797561761569935E-2
-                    0x3f5384e3e686bfabULL, // 1.19135147006586384913E-3
-                    0x3f24fcb839982153ULL  // 1.60119522476751861407E-4
-                >(x) /
+                              0x3ff0000000000000ULL,  // 9.99999999999999996796E-1
+                              0x3fdfa1373993e312ULL,  // 4.94214826801497100753E-1
+                              0x3fca8da9dcae7d31ULL,  // 2.07448227648435975150E-1
+                              0x3fa863d918c423d3ULL,  // 4.76367800457137231464E-2
+                              0x3f8557cde9db14b0ULL,  // 1.04213797561761569935E-2
+                              0x3f5384e3e686bfabULL,  // 1.19135147006586384913E-3
+                              0x3f24fcb839982153ULL  // 1.60119522476751861407E-4
+                              >(x) /
                     horner<B,
-                    0x3ff0000000000000ULL, //  1.00000000000000000320E00
-                    0x3fb24944c9cd3c51ULL, //  7.14304917030273074085E-2
-                    0xbfce071a9d4287c2ULL, // -2.34591795718243348568E-1
-                    0x3fa25779e33fde67ULL, //  3.58236398605498653373E-2
-                    0x3f8831ed5b1bb117ULL, //  1.18139785222060435552E-2
-                    0xBf7240e4e750b44aULL, // -4.45641913851797240494E-3
-                    0x3f41ae8a29152573ULL, //  5.39605580493303397842E-4
-                    0xbef8487a8400d3aFULL  // -2.31581873324120129819E-5
-                    >(x);
+                           0x3ff0000000000000ULL,  //  1.00000000000000000320E00
+                           0x3fb24944c9cd3c51ULL,  //  7.14304917030273074085E-2
+                           0xbfce071a9d4287c2ULL,  // -2.34591795718243348568E-1
+                           0x3fa25779e33fde67ULL,  //  3.58236398605498653373E-2
+                           0x3f8831ed5b1bb117ULL,  //  1.18139785222060435552E-2
+                           0xBf7240e4e750b44aULL,  // -4.45641913851797240494E-3
+                           0x3f41ae8a29152573ULL,  //  5.39605580493303397842E-4
+                           0xbef8487a8400d3aFULL  // -2.31581873324120129819E-5
+                           >(x);
             }
         };
     }
@@ -264,7 +263,7 @@ namespace xsimd
         {
             auto nan_result = (a < B(0.) && is_flint(a));
 #ifndef XSIMD_NO_INVALIDS
-            nan_result = is_nan(a) || nan_result;
+            nan_result = isnan(a) || nan_result;
 #endif
             B q = abs(a);
             auto test = (a < B(-33.));
@@ -291,8 +290,8 @@ namespace xsimd
      * lgamma implementation *
      *************************/
 
-     /* origin: boost/simd/arch/common/detail/generic/gammaln_kernel.hpp */
-     /*
+    /* origin: boost/simd/arch/common/detail/generic/gammaln_kernel.hpp */
+    /*
      * ====================================================
      * copyright 2016 NumScale SAS
      *
@@ -311,38 +310,38 @@ namespace xsimd
             static inline B gammalnB(const B& x)
             {
                 return horner<B,
-                    0x3ed87730, //    4.227843421859038E-001
-                    0x3ea51a64, //    3.224669577325661E-001,
-                    0xbd89f07e, //   -6.735323259371034E-002,
-                    0x3ca89ed8, //    2.058355474821512E-002,
-                    0xbbf164fd, //   -7.366775108654962E-003,
-                    0x3b3ba883, //    2.863437556468661E-003,
-                    0xbaabeab1, //   -1.311620815545743E-003,
-                    0x3a1ebb94  //    6.055172732649237E-004
-                >(x);
+                              0x3ed87730,  //    4.227843421859038E-001
+                              0x3ea51a64,  //    3.224669577325661E-001,
+                              0xbd89f07e,  //   -6.735323259371034E-002,
+                              0x3ca89ed8,  //    2.058355474821512E-002,
+                              0xbbf164fd,  //   -7.366775108654962E-003,
+                              0x3b3ba883,  //    2.863437556468661E-003,
+                              0xbaabeab1,  //   -1.311620815545743E-003,
+                              0x3a1ebb94  //    6.055172732649237E-004
+                              >(x);
             }
 
             static inline B gammalnC(const B& x)
             {
                 return horner<B,
-                    0xbf13c468,  //   -5.772156501719101E-001
-                    0x3f528d34,  //    8.224670749082976E-001,
-                    0xbecd27a8,  //   -4.006931650563372E-001,
-                    0x3e8a898b,  //    2.705806208275915E-001,
-                    0xbe53c04f,  //   -2.067882815621965E-001,
-                    0x3e2d4dab,  //    1.692415923504637E-001,
-                    0xbe22d329,  //   -1.590086327657347E-001,
-                    0x3e0c3c4f   //    1.369488127325832E-001
-                >(x);
+                              0xbf13c468,  //   -5.772156501719101E-001
+                              0x3f528d34,  //    8.224670749082976E-001,
+                              0xbecd27a8,  //   -4.006931650563372E-001,
+                              0x3e8a898b,  //    2.705806208275915E-001,
+                              0xbe53c04f,  //   -2.067882815621965E-001,
+                              0x3e2d4dab,  //    1.692415923504637E-001,
+                              0xbe22d329,  //   -1.590086327657347E-001,
+                              0x3e0c3c4f  //    1.369488127325832E-001
+                              >(x);
             }
 
             static inline B gammaln2(const B& x)
             {
                 return horner<B,
-                    0x3daaaa94, //   8.333316229807355E-002f
-                    0xbb358701, //  -2.769887652139868E-003f,
-                    0x3a31fd69  //   6.789774945028216E-004f
-                >(x);
+                              0x3daaaa94,  //   8.333316229807355E-002f
+                              0xbb358701,  //  -2.769887652139868E-003f,
+                              0x3a31fd69  //   6.789774945028216E-004f
+                              >(x);
             }
         };
 
@@ -352,33 +351,33 @@ namespace xsimd
             static inline B gammaln1(const B& x)
             {
                 return horner<B,
-                    0xc12a0c675418055ell, //  -8.53555664245765465627E5
-                    0xc13a45890219f20bll, //  -1.72173700820839662146E6,
-                    0xc131bc82f994db51ll, //  -1.16237097492762307383E6,
-                    0xc1143d73f89089e5ll, //  -3.31612992738871184744E5,
-                    0xc0e2f234355bb93ell, //  -3.88016315134637840924E4,
-                    0xc09589018ff36761ll  //  -1.37825152569120859100E3
-                >(x) /
+                              0xc12a0c675418055ell,  //  -8.53555664245765465627E5
+                              0xc13a45890219f20bll,  //  -1.72173700820839662146E6,
+                              0xc131bc82f994db51ll,  //  -1.16237097492762307383E6,
+                              0xc1143d73f89089e5ll,  //  -3.31612992738871184744E5,
+                              0xc0e2f234355bb93ell,  //  -3.88016315134637840924E4,
+                              0xc09589018ff36761ll  //  -1.37825152569120859100E3
+                              >(x) /
                     horner<B,
-                    0xc13ece4b6a11e14all, //  -2.01889141433532773231E6
-                    0xc1435255892ff34cll, //  -2.53252307177582951285E6,
-                    0xc131628671950043ll, //  -1.13933444367982507207E6,
-                    0xc10aeb84b9744c9bll, //  -2.20528590553854454839E5,
-                    0xc0d0aa0d7b89d757ll, //  -1.70642106651881159223E4,
-                    0xc075fd0d1cf312b2ll, //  -3.51815701436523470549E2,
-                    0x3ff0000000000000ll  //   1.00000000000000000000E0
-                    >(x);
+                           0xc13ece4b6a11e14all,  //  -2.01889141433532773231E6
+                           0xc1435255892ff34cll,  //  -2.53252307177582951285E6,
+                           0xc131628671950043ll,  //  -1.13933444367982507207E6,
+                           0xc10aeb84b9744c9bll,  //  -2.20528590553854454839E5,
+                           0xc0d0aa0d7b89d757ll,  //  -1.70642106651881159223E4,
+                           0xc075fd0d1cf312b2ll,  //  -3.51815701436523470549E2,
+                           0x3ff0000000000000ll  //   1.00000000000000000000E0
+                           >(x);
             }
 
             static inline B gammalnA(const B& x)
             {
                 return horner<B,
-                    0x3fb555555555554bll,//    8.33333333333331927722E-2
-                    0xbf66c16c16b0a5a1ll,//   -2.77777777730099687205E-3,
-                    0x3f4a019f20dc5ebbll,//    7.93650340457716943945E-4,
-                    0xbf437fbdb580e943ll,//   -5.95061904284301438324E-4,
-                    0x3f4a985027336661ll //    8.11614167470508450300E-4
-                >(x);
+                              0x3fb555555555554bll,  //    8.33333333333331927722E-2
+                              0xbf66c16c16b0a5a1ll,  //   -2.77777777730099687205E-3,
+                              0x3f4a019f20dc5ebbll,  //    7.93650340457716943945E-4,
+                              0xbf437fbdb580e943ll,  //   -5.95061904284301438324E-4,
+                              0x3f4a985027336661ll  //    8.11614167470508450300E-4
+                              >(x);
             }
         };
     }
@@ -603,7 +602,6 @@ namespace xsimd
     {
         return detail::lgamma_impl<batch<T, N>>::compute(x);
     }
-
 }
 
 #endif
