@@ -10,6 +10,7 @@
 #define XSIMD_AVX_INT64_HPP
 
 #include <cstdint>
+
 #include "xsimd_base.hpp"
 
 namespace xsimd
@@ -22,7 +23,6 @@ namespace xsimd
     template <>
     class batch_bool<int64_t, 4> : public simd_batch_bool<batch_bool<int64_t, 4>>
     {
-
     public:
 
         batch_bool();
@@ -82,9 +82,27 @@ namespace xsimd
         batch& load_aligned(const int64_t* src);
         batch& load_unaligned(const int64_t* src);
 
+        batch& load_aligned(const int32_t* src);
+        batch& load_unaligned(const int32_t* src);
+
+        batch& load_aligned(const float* src);
+        batch& load_unaligned(const float* src);
+
+        batch& load_aligned(const double* src);
+        batch& load_unaligned(const double* src);
+
         void store_aligned(int64_t* dst) const;
         void store_unaligned(int64_t* dst) const;
 
+        void store_aligned(int32_t* dst) const;
+        void store_unaligned(int32_t* dst) const;
+
+        void store_aligned(float* dst) const;
+        void store_unaligned(float* dst) const;
+
+        void store_aligned(double* dst) const;
+        void store_unaligned(double* dst) const;
+
         int64_t operator[](std::size_t index) const;
 
     private:
@@ -132,19 +150,19 @@ namespace xsimd
 
 #if XSIMD_X86_INSTR_SET < XSIMD_X86_AVX2_VERSION
 
-#define XSIMD_SPLIT_AVX(name)\
-    __m128i name##_low = _mm256_castsi256_si128(name);\
+#define XSIMD_SPLIT_AVX(name)                          \
+    __m128i name##_low = _mm256_castsi256_si128(name); \
     __m128i name##_high = _mm256_extractf128_si256(name, 1)
 
-#define XSIMD_RETURN_MERGED_SSE(res_low, res_high)\
-    __m256i result = _mm256_castsi128_si256(res_low);\
+#define XSIMD_RETURN_MERGED_SSE(res_low, res_high)    \
+    __m256i result = _mm256_castsi128_si256(res_low); \
     return _mm256_insertf128_si256(result, res_high, 1)
 
-#define XSIMD_APPLY_SSE_FUNCTION(func, avx_lhs, avx_rhs)\
-    XSIMD_SPLIT_AVX(avx_lhs);\
-    XSIMD_SPLIT_AVX(avx_rhs);\
-    __m128i res_low = func(avx_lhs##_low, avx_rhs##_low);\
-    __m128i res_high = func(avx_lhs##_high, avx_rhs##_high);\
+#define XSIMD_APPLY_SSE_FUNCTION(func, avx_lhs, avx_rhs)     \
+    XSIMD_SPLIT_AVX(avx_lhs);                                \
+    XSIMD_SPLIT_AVX(avx_rhs);                                \
+    __m128i res_low = func(avx_lhs##_low, avx_rhs##_low);    \
+    __m128i res_high = func(avx_lhs##_high, avx_rhs##_high); \
     XSIMD_RETURN_MERGED_SSE(res_low, res_high);
 #endif
 
@@ -311,6 +329,61 @@ namespace xsimd
         return *this;
     }
 
+    inline batch<int64_t, 4>& batch<int64_t, 4>::load_aligned(const int32_t* src)
+    {
+#if XSIMD_X86_INSTR_SET >= XSIMD_X86_AVX2_VERSION
+        m_value = _mm256_cvtepi32_epi64(_mm_load_si128((__m128i const*)src));
+        return *this;
+#else
+        alignas(32) int64_t tmp[4];
+        tmp[0] = int64_t(src[0]);
+        tmp[1] = int64_t(src[1]);
+        tmp[2] = int64_t(src[2]);
+        tmp[3] = int64_t(src[3]);
+        return load_aligned(tmp);
+#endif
+    }
+
+    inline batch<int64_t, 4>& batch<int64_t, 4>::load_unaligned(const int32_t* src)
+    {
+#if XSIMD_X86_INSTR_SET >= XSIMD_X86_AVX2_VERSION
+        m_value = _mm256_cvtepi32_epi64(_mm_loadu_si128((__m128i const*)src));
+        return *this;
+#else
+        return load_aligned(src);
+#endif
+    }
+
+    inline batch<int64_t, 4>& batch<int64_t, 4>::load_aligned(const float* src)
+    {
+        alignas(32) int64_t tmp[4];
+        tmp[0] = static_cast<int64_t>(src[0]);
+        tmp[1] = static_cast<int64_t>(src[1]);
+        tmp[2] = static_cast<int64_t>(src[2]);
+        tmp[3] = static_cast<int64_t>(src[3]);
+        return load_aligned(tmp);
+    }
+
+    inline batch<int64_t, 4>& batch<int64_t, 4>::load_unaligned(const float* src)
+    {
+        return load_aligned(src);
+    }
+
+    inline batch<int64_t, 4>& batch<int64_t, 4>::load_aligned(const double* src)
+    {
+        alignas(32) int64_t tmp[4];
+        tmp[0] = static_cast<int64_t>(src[0]);
+        tmp[1] = static_cast<int64_t>(src[1]);
+        tmp[2] = static_cast<int64_t>(src[2]);
+        tmp[3] = static_cast<int64_t>(src[3]);
+        return load_aligned(tmp);
+    }
+
+    inline batch<int64_t, 4>& batch<int64_t, 4>::load_unaligned(const double* src)
+    {
+        return load_aligned(src);
+    }
+
     inline void batch<int64_t, 4>::store_aligned(int64_t* dst) const
     {
         _mm256_store_si256((__m256i*)dst, m_value);
@@ -321,6 +394,51 @@ namespace xsimd
         _mm256_storeu_si256((__m256i*)dst, m_value);
     }
 
+    inline void batch<int64_t, 4>::store_aligned(int32_t* dst) const
+    {
+        alignas(32) int64_t tmp[4];
+        store_aligned(tmp);
+        dst[0] = static_cast<int32_t>(tmp[0]);
+        dst[1] = static_cast<int32_t>(tmp[1]);
+        dst[2] = static_cast<int32_t>(tmp[2]);
+        dst[3] = static_cast<int32_t>(tmp[3]);
+    }
+
+    inline void batch<int64_t, 4>::store_unaligned(int32_t* dst) const
+    {
+        store_aligned(dst);
+    }
+
+    inline void batch<int64_t, 4>::store_aligned(float* dst) const
+    {
+        alignas(32) int64_t tmp[4];
+        store_aligned(tmp);
+        dst[0] = float(tmp[0]);
+        dst[1] = float(tmp[1]);
+        dst[2] = float(tmp[2]);
+        dst[3] = float(tmp[3]);
+    }
+
+    inline void batch<int64_t, 4>::store_unaligned(float* dst) const
+    {
+        store_aligned(dst);
+    }
+
+    inline void batch<int64_t, 4>::store_aligned(double* dst) const
+    {
+        alignas(32) int64_t tmp[4];
+        store_aligned(tmp);
+        dst[0] = double(tmp[0]);
+        dst[1] = double(tmp[1]);
+        dst[2] = double(tmp[2]);
+        dst[3] = double(tmp[3]);
+    }
+
+    inline void batch<int64_t, 4>::store_unaligned(double* dst) const
+    {
+        store_aligned(dst);
+    }
+
     inline int64_t batch<int64_t, 4>::operator[](std::size_t index) const
     {
         alignas(32) int64_t x[4];
@@ -475,7 +593,7 @@ namespace xsimd
     {
 #if XSIMD_X86_INSTR_SET >= XSIMD_X86_AVX2_VERSION
         __m256i sign = _mm256_cmpgt_epi64(_mm256_setzero_si256(), rhs);
-        __m256i inv  = _mm256_xor_si256(rhs, sign);
+        __m256i inv = _mm256_xor_si256(rhs, sign);
         return _mm256_sub_epi64(inv, sign);
 #else
         XSIMD_SPLIT_AVX(rhs);
@@ -498,7 +616,7 @@ namespace xsimd
     {
         return x * y - z;
     }
-    
+
     inline batch<int64_t, 4> fnma(const batch<int64_t, 4>& x, const batch<int64_t, 4>& y, const batch<int64_t, 4>& z)
     {
         return -x * y + z;
@@ -528,8 +646,7 @@ namespace xsimd
 #if defined(__x86_64__)
         return _mm_cvtsi128_si64(res);
 #else
-        union
-        {
+        union {
             int64_t i;
             __m128i m;
         } u;
@@ -575,7 +692,6 @@ namespace xsimd
         XSIMD_RETURN_MERGED_SSE(res_low, res_high);
 #endif
     }
-
 }
 
 #undef XSIMD_APPLY_SSE_FUNCTION
@@ -583,4 +699,3 @@ namespace xsimd
 #undef XSIMD_SPLIT_AVX
 
 #endif
-
